summaryrefslogtreecommitdiff
path: root/common/src/leap/soledad/common/tests/u1db_tests/test_document.py
diff options
context:
space:
mode:
Diffstat (limited to 'common/src/leap/soledad/common/tests/u1db_tests/test_document.py')
-rw-r--r--common/src/leap/soledad/common/tests/u1db_tests/test_document.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/common/src/leap/soledad/common/tests/u1db_tests/test_document.py b/common/src/leap/soledad/common/tests/u1db_tests/test_document.py
index 23502b4b..4e8bcaf9 100644
--- a/common/src/leap/soledad/common/tests/u1db_tests/test_document.py
+++ b/common/src/leap/soledad/common/tests/u1db_tests/test_document.py
@@ -1,8 +1,9 @@
# Copyright 2011 Canonical Ltd.
+# Copyright 2016 LEAP Encryption Access Project
#
-# This file is part of u1db.
+# This file is part of leap.soledad.common
#
# u1db is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.
#
@@ -13,10 +14,9 @@
#
# You should have received a copy of the GNU Lesser General Public License
# along with u1db. If not, see <http://www.gnu.org/licenses/>.
-
-
from unittest import skip
-from u1db import errors
+
+from leap.soledad.common.l2db import errors
from leap.soledad.common.tests import u1db_tests as tests
@@ -1,8 +1,9 @@
#
-# u1db is free software: you can redistribute it and/or modify
+# leap.soledad.common is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3
# as published by the Free Software Foundation.